@@ -9,6 +9,63 @@ from scipy.special import comb
 plt.rcParams['axes.unicode_minus'] =False
 
 
+def _image_detail(data, labels, index, top, estimate, n1, n2):
+    if not index:
+        index = np.arange(0, data.shape[0], dtype=int)
+    new_data = data[index]
+    
+    # 从大到小排序
+    sort_list = np.argsort(new_data)
+    new_data = np.sort(new_data)
+    
+    if not labels:
+        labels = sort_list
+    else:
+        labels = np.array(labels, dtype=str)
+        labels = labels[sort_list]
+    
+    if not top:
+        top = data.shape[0]
+    new_data = new_data[-top:]
+    labels = labels[-top:]
+    
+    width = new_data.shape[0] * 0.5 * n1
+    fig = plt.figure(figsize=(8, width))
+    ax = fig.add_subplot(n1, 1, n2)
+    color = []
+    for i in range(new_data.shape[0]):
+        if new_data[i] >= 0:
+            color.append('#FFE100')
+        else:
+            color.append('#1E90FF')
+    
+    rows = ax.barh(range(new_data.shape[0]), new_data, color=color)
+    for rect in rows:
+        w = rect.get_width()
+        if w >= 0:
+            ha = 'left'
+        else:
+            ha = 'right'
+        if not estimate:
+            new_w = w
+        else:
+            new_w = np.around(w, estimate)
+        ax.text(w, rect.get_y()+rect.get_height()/2, new_w, ha=ha, va='center')
+    
+    ax.set_yticks(range(new_data.shape[0]))
+    ax.set_yticklabels(labels)
+    plt.xticks(())
+
+
+def _image_process(data, labels, index, top, estimate):
+    if len(data.shape) == 1:
+        _image_detail(data, labels, index, top, estimate, 1, 1)
+    elif len(data.shape) == 2:
+        num = data.shape[0]
+        for j in range(num):
+            _image_detail(data[j], labels, index, top, estimate, num, j+1)
+
+
 def sense(func, x0, acc=0.1):
     '''
     灵敏度分析
@@ -92,8 +149,8 @@ class Error():
     ----
     abs_error：1-D ndarray数组，绝对误差列表
     rel_error：1-D ndarray数组，相对误差列表
-    abs_sort：绝对误差从大到小的排序
-    rel_sort：相对误差从大到小的排序
+    abs_sort：元组列表，绝对误差从大到小的排序
+    rel_sort：元组列表，相对误差从大到小的排序
     mae：平均绝对误差
     mape：平均绝对百分比误差
     mse：平均平方误差
@@ -112,8 +169,8 @@ class Error():
     ----------
     abs_error: 1-D ndarray, absolute error list
     rel_error: 1-D ndarray, relative error list
-    abs_sort: list of absolute values of errors sorted from large to small
-    rel_sort: list of relative values of errors sorted from large to small
+    abs_sort: 1-D ndarray, list of absolute values of errors sorted from large to small
+    rel_sort: 1-D ndarray, list of relative values of errors sorted from large to small
     mae: mean absolute error
     mape: mean absolute percentage error
     mse: mean squared error
@@ -126,6 +183,22 @@ class Error():
     
     
     def fit(self, data, target):
+        '''
+        计算误差
+        
+        参数
+        ----
+        data：ndarray，数据集的自变量
+        target：ndarray，数据集的因变量
+        
+        
+        Calculate the error
+        
+        Parameters
+        ----------
+        data: ndarray, independent variable of data set
+        target: ndarray, dependent variable of data set
+        '''
         data = np.array(data)
         target = np.array(target)
         self.__num_data = len(target)
@@ -212,51 +285,7 @@ class SHAP_and_Shapley():
         return np.array(shap_and_shapley_values)
     
     
-    def __image_process(self, labels, index, top):
-        if not index:
-            index = np.arange(0, self.values.shape[0], dtype=np.int)
-        new_values = self.values[index]
-        
-        # 从大到小排序
-        sort_list = np.argsort(new_values)
-        new_values = np.sort(new_values)
-        
-        if not labels:
-            labels = sort_list
-        else:
-            labels = np.array(labels, dtype=np.str)
-            labels = labels[sort_list]
-        
-        if not top:
-            top = self.values.shape[0]
-        new_values = new_values[-top:]
-        labels = labels[-top:]
-        
-        width = new_values.shape[0] * 0.5
-        fig = plt.figure(figsize=(8, width))
-        ax = fig.add_subplot(1, 1, 1)
-        color = []
-        for i in range(new_values.shape[0]):
-            if new_values[i] >= 0:
-                color.append('#FFE100')
-            else:
-                color.append('#1E90FF')
-        
-        rows = ax.barh(range(new_values.shape[0]), new_values, color=color)
-        for rect in rows:
-            w = rect.get_width()
-            if w >= 0:
-                ha = 'left'
-            else:
-                ha = 'right'
-            ax.text(w, rect.get_y()+rect.get_height()/2, w, ha=ha, va='center')
-        
-        ax.set_yticks(range(new_values.shape[0]))
-        ax.set_yticklabels(labels)
-        plt.xticks(())
-    
-    
-    def show(self, labels=None, index=None, top=None):
+    def show(self, labels=None, index=None, top=None, estimate=None):
         '''
         作图并显示
         
@@ -265,6 +294,7 @@ class SHAP_and_Shapley():
         labels：一维列表，可选，特征名称，默认为None
         index：一维列表，可选，特征索引，默认为None，表示全选
         top：整型，可选，表示显示值最高的前top个特征，默认为None，表示全选
+        estimate：整型，可选，表示图示示数保留的小数位数，默认为None
         
         
         Display the image
@@ -274,12 +304,13 @@ class SHAP_and_Shapley():
         labels: 1-D list, callable, names of features, default=None
         index: 1-D list, callable, index of features, default=None, which means select all
         top: int, callable, display "top" features with the highest values, default=None, which means select all
+        estimate: int, callable, indicating the number of decimal places reserved for the graphic display, default=None
         '''
-        self.__image_process(labels, index, top)
+        _image_process(self.values, labels, index, top, estimate)
         plt.show()
     
     
-    def savefig(self, filename, labels=None, index=None, top=None):
+    def savefig(self, filename, labels=None, index=None, top=None, estimate=None):
         '''
         作图并保存
         
@@ -289,6 +320,7 @@ class SHAP_and_Shapley():
         labels：一维列表，可选，特征名称，默认为None
         index：一维列表，可选，特征索引，默认为None，表示全选
         top：整型，可选，表示显示值最高的前top个特征，默认为None，表示全选
+        estimate：整型，可选，表示图示示数保留的小数位数，默认为None
         
         
         Save the image
@@ -299,8 +331,9 @@ class SHAP_and_Shapley():
         labels: 1-D list, callable, names of features, default=None
         index: 1-D list, callable, index of features, default=None, which means select all
         top: int, callable, display "top" features with the highest values, default=None, which means select all
+        estimate: int, callable, indicating the number of decimal places reserved for the graphic display, default=None
         '''
-        self.__image_process(labels, index, top)
+        _image_process(self.values, labels, index, top, estimate)
         plt.savefig(filename)
 
 
@@ -407,4 +440,166 @@ class Shapley(SHAP_and_Shapley):
             replace = replace(data)
         
         self.values = SHAP_and_Shapley._pre_fit(self, data, replace).T
-        self.values = self.values.mean(axis=0)
\ No newline at end of file
+        self.values = self.values.mean(axis=0)
+
+
+class Lime():
+    '''
+    局部代理
+    对局部点进行扰动并输入模型得到新的数据集
+    以新数据集为基础，拟合出新的线性模型AX+b用于局部代替黑盒模型
+    利用该线性模型对黑盒模型进行解释
+    预测值 = Σweight + intercept
+    
+    参数
+    ----
+    predict_f：函数类型，原模型的预测函数，仅支持批量输入函数
+    
+    属性
+    ----
+    coef：ndarray，线性模型的系数
+    intercept：数或一维ndarray，线性模型的截距
+    weight：一维ndarray，各个特征对预测值的贡献
+    
+    
+    Local Interpretable Model-agnostic Explanation
+    perturb the local points and put them into the model to get a new data set
+    fit a linear model Ax + b to replace the black box model base on the new data set
+    explain the black box model with the linear model
+    prediction = Σweight + intercept
+    
+    Parameter
+    ---------
+    predict_f: function, the predict function of the model, only batch input functions are supported
+    
+    Attributes
+    ----------
+    coef: ndarray, coeficcient of linear model
+    intercept: num or 1-D ndarray, intercept of linear model
+    weight: 1-D ndarray, contribution to the prediction of each feature
+    '''
+    def __init__(self, predict_f):
+        self.predict_f = predict_f
+    
+    
+    def fit(self, data, acc=0.1, num=100, random_state=None):
+        '''
+        进行Lime计算
+        
+        参数
+        ----
+        data：数组，局部点
+        acc：浮点数类型，可选，邻域范围，默认为0.1
+        num：整型，可选，在领域抽样点的数量，默认为100
+        random_state：整型，可选，随机种子
+        
+        
+        Calculate
+        
+        Parameters
+        ----------
+        data: ndarray, local point
+        acc: float, callable, neighborhood range， default=0.1
+        num: int, callable
+        random_state: int, callable, random seed
+        '''
+        data = np.array(data)
+        np.random.seed(random_state)
+        X_set = np.random.rand(num, *data.shape) * 2 * acc - acc
+        X_set += data
+        y_set = self.predict_f(X_set)
+        shape = X_set.shape
+        X_set = X_set.reshape(shape[0], -1)
+        X_set = np.hstack((X_set, np.ones((X_set.shape[0], 1))))
+        A = np.linalg.lstsq(X_set, y_set, rcond=None)[0]
+        
+        self.intercept = A[-1]
+        A = A[:-1].T
+        if len(A.shape) == 1:
+            self.coef = A
+        else:
+            self.coef = A.reshape(A.shape[0], *shape[1:])
+        self.weight = self.coef * data
+    
+    
+    def predict(self, data):
+        '''
+        利用近似的线性模型进行预测
+        
+        参数
+        ----
+        data：小批量输入数组，需要预测的数据
+        
+        
+        Use approximate linear model to predict
+        
+        Parameter
+        ---------
+        data: barch input ndarray, input data
+        '''
+        if len(self.intercept.shape) == 0:
+            result = data * self.coef
+            retult = result.reshape(result.shape[0], -1)
+            result = result.sum(axis=1) + self.intercept
+            return result
+        
+        else:
+            all_result = []
+            for i in range(self.coef.shape[0]):
+                result = data * self.coef[i]
+                result = result.reshape(result.shape[0], -1)
+                result = result.sum(axis=1) + self.intercept[i]
+                all_result.append(result)
+            return np.array(all_result).T
+    
+    
+    def show(self, labels=None, index=None, top=None, estimate=None):
+        '''
+        作图并显示
+        
+        参数
+        ----
+        labels：一维列表，可选，特征名称，默认为None
+        index：一维列表，可选，特征索引，默认为None，表示全选
+        top：整型，可选，表示显示值最高的前top个特征，默认为None，表示全选
+        estimate：整型，可选，表示图示示数保留的小数位数，默认为None
+        
+        
+        Display the image
+        
+        Parameters
+        ----------
+        labels: 1-D list, callable, names of features, default=None
+        index: 1-D list, callable, index of features, default=None, which means select all
+        top: int, callable, display "top" features with the highest values, default=None, which means select all
+        estimate: int, callable, indicating the number of decimal places reserved for the graphic display, default=None
+        '''
+        _image_process(self.weight, labels, index, top, estimate)
+        plt.show()
+    
+    
+    def savefig(self, filename, labels=None, index=None, top=None, estimate=None):
+        '''
+        作图并保存
+        
+        参数
+        ----
+        filename：字符串类型，文件名
+        labels：一维列表，可选，特征名称，默认为None
+        index：一维列表，可选，特征索引，默认为None，表示全选
+        top：整型，可选，表示显示值最高的前top个特征，默认为None，表示全选
+        estimate：整型，可选，表示图示示数保留的小数位数，默认为None
+        
+        
+        Save the image
+        
+        Parameters
+        ----------
+        filename: str, file name
+        labels: 1-D list, callable, names of features, default=None
+        index: 1-D list, callable, index of features, default=None, which means select all
+        top: int, callable, display "top" features with the highest values, default=None, which means select all
+        estimate: int, callable, indicating the number of decimal places reserved for the graphic display, default=None
+        '''
+        _image_process(self.weight, labels, index, top, estimate)
+        plt.savefig(filename)
\ No newline at end of file
